==> haskell-input-parsers-0.3.0.2-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-AYv46NACOyjz57dqLcYoq
key:                  input-parsers-0.3.0.2-AYv46NACOyjz57dqLcYoq
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  7b4e0d12e279408f281d3798adae2897
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-AYv46NACOyjz57dqLcYoq
depends:
    attoparsec-0.14.4-Ie40PJLLZWYz4b9BsvrTL base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6-7i89ai3tGrk1Q7VAuxRTfc parsec-3.1.16.1
    parsers-0.12.12-J6vV8xNzLL92SUgHZUP3VD text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-input-parsers-0.3.0.2-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-K2W2HUFjHI0jfcSI2tP4v
key:                  input-parsers-0.3.0.2-K2W2HUFjHI0jfcSI2tP4v
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  2b59a00f74f24675b13155269d978885
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-K2W2HUFjHI0jfcSI2tP4v
depends:
    attoparsec-0.14.4-4svHBw0u1Cc40MQ1AjsKLc base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6-6Z43uGik5WGFCsg4TdOhuU parsec-3.1.16.1
    parsers-0.12.12-7PEU0i9OZOhIj5xUnqMhs text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
